#
# spec file for package bitmap
#
# Copyright (c) 2024 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           bitmap
Version:        1.1.1
Release:        1.6
Summary:        X bitmap editor and converter utilities
License:        X11
Group:          System/X11/Utilities
URL:            http://xorg.freedesktop.org/
Source0:        http://xorg.freedesktop.org/releases/individual/app/%{name}-%{version}.tar.xz
BuildRequires:  fdupes
BuildRequires:  pkg-config
BuildRequires:  pkgconfig(x11)
BuildRequires:  pkgconfig(xaw7)
BuildRequires:  pkgconfig(xbitmaps)
BuildRequires:  pkgconfig(xmu)
BuildRequires:  pkgconfig(xorg-macros) >= 1.8
BuildRequires:  pkgconfig(xproto) >= 7.0.17
BuildRequires:  pkgconfig(xt)
# This was part of the xorg-x11 package up to version 7.6
Conflicts:      xorg-x11 <= 7.6
BuildRoot:      %{_tmppath}/%{name}-%{version}-build

%description
The bitmap program is a rudimentary tool for creating or editing
rectangular images made up of 1's and 0's. Bitmaps are used in X for
defining clipping regions, cursor shapes, icon shapes, and tile and
stipple patterns.

The bmtoa and atobm filters convert bitmap files to and from ASCII
strings. They are most commonly used to quickly print out bitmaps and
to generate versions for including in text.

%prep
%setup -q

%build
%configure
make %{?_smp_mflags}

%install
%make_install
%fdupes -s %{buildroot}

%files
%defattr(-,root,root)
%doc AUTHORS ChangeLog README.md
%license COPYING
%{_bindir}/atobm
%{_bindir}/bitmap
%{_bindir}/bmtoa
%{_includedir}/X11/bitmaps/
%dir %{_datadir}/X11/app-defaults
%{_datadir}/X11/app-defaults/Bitmap
%{_datadir}/X11/app-defaults/Bitmap-color
%{_datadir}/X11/app-defaults/Bitmap-nocase
%{_mandir}/man1/atobm.1%{?ext_man}
%{_mandir}/man1/bitmap.1%{?ext_man}
%{_mandir}/man1/bmtoa.1%{?ext_man}

%changelog
* Sun Feb  4 2024 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.1.1
  * configure: Use AC_SYS_LARGEFILE to enable large file support
  * Ensure all *.c files include config.h before any other headers
  * atobm, bmtoa, bitmap: Add -help and -version options
  * bitmap: Print which option was in error along with usage message
  * Remove "All rights reserved" from Oracle copyright notices
* Sun May  1 2022 Stefan Dirsch <sndirsch@suse.com>
- update to version 1.1.0
  * Use _CONST_X_STRING to make libXt declare String as const char *
  * Fix spelling/wording issues
  * gitlab CI: add a basic build test
  * Build xz tarballs instead of bzip2
  * Move bitmaps into a new bitmaps directory
  * test: add round-trip-test for atobm & bmtoa
  * atobm: accept single character lines
  * atobm: close memory leaks
  * gitlab CI: stop requiring Signed-off-by in commits
  * bitmap: Fix a crash with underspecified dimensions
* Mon Feb 11 2019 sndirsch@suse.com
- update to version 1.0.9:
  * This release fixes a long standing bug in the bitmap editor
    where operations would not work properly when NumLock was on.
* Tue Jan 20 2015 benoit.monin@gmx.fr
- update to version 1.0.8:
  * Stop memory leak in XmuWriteBitmapDataToFile()
  * Stop memory leaks from XtNewString(StripFilename(filename))
  * autogen.sh: Honor NOCONFIGURE=1
  * configure: Drop AM_MAINTAINER_MODE
  * Use '& 7' instead '%% 8' to silence clang analyzer warning
  * Demacro modernization of NewSList to plug a memory leak during
    error handling
  * Silence -Wbad-function-cast
  * Avoid shadow declarations
  * assert to avoid a NULL dereference
  * Print which option was in error along with usage message
  * config: replace deprecated use of AC_OUTPUT with
    AC_CONFIG_FILES
  * Use table markup in preference to various low-level
    constructions
* Thu Feb  6 2014 sndirsch@suse.com
- fixed license to X11 in specfile
* Mon May 20 2013 zaitor@opensuse.org
- Update to version 1.0.7:
  + Mark usage() functions as noreturn, as suggested by gcc.
  + Fix genererate typo in bmtoa error messages.
  + Combine usage messages into a single string.
  + bitmap.man:  Fix some typos.
  + Fix pixmap leak in error paths of BWGetUnzoomedPixmap.
* Sat Apr 14 2012 dimstar@opensuse.org
- Update to version 1.0.6:
  + Code clean-ups.
  + Man page fixes
  + Build system fixes
- Add pkgconfig(xproto) BuildRequires: New dependency.
* Fri Apr 13 2012 vuntz@opensuse.org
- Split bitmap from xorg-x11. Initial version: 1.0.5.
